# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-XML-SAX-Base
Summary:	Base class SAX Drivers and Filters
Version:	1.09
Release:	19.%{__distinit}%{__distvers}
# This module is split from XML::SAX, which is licensed same as perl
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/XML-SAX-Base
Source0:	https://cpan.metacpan.org/modules/by-module/XML/XML-SAX-Base-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(overload)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(Test)
# Release Tests
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.41
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(perl -MConfig -e 'print $Config{version}'))
%endif

%description
This module has a very simple task - to be a base class for PerlSAX drivers
and filters. Its default behavior is to pass the input directly to the output
unchanged. It can be useful to use this module as a base class so you don't
have to, for example, implement the characters() callback.

The main advantages that it provides are easy dispatching of events the right
way (i.e. it takes care for you of checking that the handler has implemented
that method, or has defined an AUTOLOAD), and the guarantee that filters will
pass along events that they aren't implementing to handlers downstream that
might nevertheless be interested in them.

%prep
%setup -q -n XML-SAX-Base-%{version}

# Avoid non-executable script complaints from rpmlint
chmod -c +x BuildSAXBase.pl

%build
perl Makefile.PL INSTALLDIRS=vendor
make

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test RELEASE_TESTING=1

%files
%doc Changes README
%{perl_vendorlib}/XML/
%{_mandir}/man3/XML::SAX::Base.3*
%{_mandir}/man3/XML::SAX::BuildSAXBase.3*
%{_mandir}/man3/XML::SAX::Exception.3*

%changelog
* Thu Jun 22 2023 Paul Howarth <paul@city-fan.org> - 1.09-19
- Use SPDX-format license tag

* Tue Jun  4 2019 Paul Howarth <paul@city-fan.org> - 1.09-8
- Perl 5.30 rebuild

* Thu Mar 29 2018 Paul Howarth <paul@city-fan.org> - 1.09-4
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Tue Apr  4 2017 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
  - Fix test suite to work without '.' in @INC (CPAN RT#120435)
- Drop support for EOL distributions prior to F-13:
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Mon Oct 17 2016 Paul Howarth <paul@city-fan.org> - 1.08-16
- Classify buildreqs by usage
- Simplify find command using -delete

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 1.08-12
- Drop %%defattr, redundant since rpm 4.4

* Sun Jun 24 2012 Paul Howarth <paul@city-fan.org> - 1.08-3
- BR: perl(base), perl(File::Spec)  and perl(Test)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Sep 14 2011 Paul Howarth <paul@city-fan.org> - 1.08-1
- Update to 1.08
  - Rename BuildSAXBase.PL => BuildSAXBase.pl
  - Add link to Perl SAX API Reference
- BR: perl(Carp)
- Package manpage for XML::SAX::BuildSAXBase
- Avoid non-executable script complaints from rpmlint

* Sun Sep 11 2011 Paul Howarth <paul@city-fan.org> - 1.07-1
- Update to 1.07
  - Modify BuildSAXBase.PL to include version stanzas when run manually
  - Make BuildSAXBase.PL harmless unless run with --force option

* Thu Sep  8 2011 Paul Howarth <paul@city-fan.org> - 1.06-1
- Update to 1.06
  - Switch distribution to use Dist::Zilla for packaging
  - Generate XML/SAX/Base.pm at release time rather than install time
  - Don't generate XML/SAX/Exception at all - it's static
  - Add git repo to metadata
- Add the ubiquitous ExtUtils::MakeMaker < 6.31 patch for Dist::Zilla dists
- Don't need to exclude placeholder.pl now that upstream doesn't install it
- BR: perl(Test::More) and perl(Test::Pod)
- Enable RELEASE_TESTING

* Mon Sep  5 2011 Paul Howarth <paul@city-fan.org> - 1.05-1
- Initial RPM version, split off from perl-XML-SAX
